# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dexidp/api.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x10\x64\x65xidp/api.proto\x12\x03\x61pi"\x82\x01\n\x06\x43lient\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06secret\x18\x02 \x01(\t\x12\x15\n\rredirect_uris\x18\x03 \x03(\t\x12\x15\n\rtrusted_peers\x18\x04 \x03(\t\x12\x0e\n\x06public\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x10\n\x08logo_url\x18\x07 \x01(\t"\x1a\n\x0cGetClientReq\x12\n\n\x02id\x18\x01 \x01(\t",\n\rGetClientResp\x12\x1b\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x0b.api.Client".\n\x0f\x43reateClientReq\x12\x1b\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x0b.api.Client"G\n\x10\x43reateClientResp\x12\x16\n\x0e\x61lready_exists\x18\x01 \x01(\x08\x12\x1b\n\x06\x63lient\x18\x02 \x01(\x0b\x32\x0b.api.Client"\x1d\n\x0f\x44\x65leteClientReq\x12\n\n\x02id\x18\x01 \x01(\t"%\n\x10\x44\x65leteClientResp\x12\x11\n\tnot_found\x18\x01 \x01(\x08"k\n\x0fUpdateClientReq\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rredirect_uris\x18\x02 \x03(\t\x12\x15\n\rtrusted_peers\x18\x03 \x03(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x10\n\x08logo_url\x18\x05 \x01(\t"%\n\x10UpdateClientResp\x12\x11\n\tnot_found\x18\x01 \x01(\x08"J\n\x08Password\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x0c\n\x04hash\x18\x02 \x01(\x0c\x12\x10\n\x08username\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\t"4\n\x11\x43reatePasswordReq\x12\x1f\n\x08password\x18\x01 \x01(\x0b\x32\r.api.Password",\n\x12\x43reatePasswordResp\x12\x16\n\x0e\x61lready_exists\x18\x01 \x01(\x08"J\n\x11UpdatePasswordReq\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08new_hash\x18\x02 \x01(\x0c\x12\x14\n\x0cnew_username\x18\x03 \x01(\t"\'\n\x12UpdatePasswordResp\x12\x11\n\tnot_found\x18\x01 \x01(\x08""\n\x11\x44\x65letePasswordReq\x12\r\n\x05\x65mail\x18\x01 \x01(\t"\'\n\x12\x44\x65letePasswordResp\x12\x11\n\tnot_found\x18\x01 \x01(\x08"\x11\n\x0fListPasswordReq"4\n\x10ListPasswordResp\x12 \n\tpasswords\x18\x01 \x03(\x0b\x32\r.api.Password"\x0c\n\nVersionReq"*\n\x0bVersionResp\x12\x0e\n\x06server\x18\x01 \x01(\t\x12\x0b\n\x03\x61pi\x18\x02 \x01(\x05"W\n\x0fRefreshTokenRef\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x12\n\ncreated_at\x18\x05 \x01(\x03\x12\x11\n\tlast_used\x18\x06 \x01(\x03"!\n\x0eListRefreshReq\x12\x0f\n\x07user_id\x18\x01 \x01(\t"?\n\x0fListRefreshResp\x12,\n\x0erefresh_tokens\x18\x01 \x03(\x0b\x32\x14.api.RefreshTokenRef"6\n\x10RevokeRefreshReq\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t"&\n\x11RevokeRefreshResp\x12\x11\n\tnot_found\x18\x01 \x01(\x08"4\n\x11VerifyPasswordReq\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t"9\n\x12VerifyPasswordResp\x12\x10\n\x08verified\x18\x01 \x01(\x08\x12\x11\n\tnot_found\x18\x02 \x01(\x08\x32\xfd\x05\n\x03\x44\x65x\x12\x34\n\tGetClient\x12\x11.api.GetClientReq\x1a\x12.api.GetClientResp"\x00\x12=\n\x0c\x43reateClient\x12\x14.api.CreateClientReq\x1a\x15.api.CreateClientResp"\x00\x12=\n\x0cUpdateClient\x12\x14.api.UpdateClientReq\x1a\x15.api.UpdateClientResp"\x00\x12=\n\x0c\x44\x65leteClient\x12\x14.api.DeleteClientReq\x1a\x15.api.DeleteClientResp"\x00\x12\x43\n\x0e\x43reatePassword\x12\x16.api.CreatePasswordReq\x1a\x17.api.CreatePasswordResp"\x00\x12\x43\n\x0eUpdatePassword\x12\x16.api.UpdatePasswordReq\x1a\x17.api.UpdatePasswordResp"\x00\x12\x43\n\x0e\x44\x65letePassword\x12\x16.api.DeletePasswordReq\x1a\x17.api.DeletePasswordResp"\x00\x12>\n\rListPasswords\x12\x14.api.ListPasswordReq\x1a\x15.api.ListPasswordResp"\x00\x12\x31\n\nGetVersion\x12\x0f.api.VersionReq\x1a\x10.api.VersionResp"\x00\x12:\n\x0bListRefresh\x12\x13.api.ListRefreshReq\x1a\x14.api.ListRefreshResp"\x00\x12@\n\rRevokeRefresh\x12\x15.api.RevokeRefreshReq\x1a\x16.api.RevokeRefreshResp"\x00\x12\x43\n\x0eVerifyPassword\x12\x16.api.VerifyPasswordReq\x1a\x17.api.VerifyPasswordResp"\x00\x42\x36\n\x12\x63om.coreos.dex.apiZ github.com/dexidp/dex/api/v2;apib\x06proto3'
)

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, "dexidp.api_pb2", _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
    _globals["DESCRIPTOR"]._options = None
    _globals["DESCRIPTOR"]._serialized_options = (
        b"\n\022com.coreos.dex.apiZ github.com/dexidp/dex/api/v2;api"
    )
    _globals["_CLIENT"]._serialized_start = 26
    _globals["_CLIENT"]._serialized_end = 156
    _globals["_GETCLIENTREQ"]._serialized_start = 158
    _globals["_GETCLIENTREQ"]._serialized_end = 184
    _globals["_GETCLIENTRESP"]._serialized_start = 186
    _globals["_GETCLIENTRESP"]._serialized_end = 230
    _globals["_CREATECLIENTREQ"]._serialized_start = 232
    _globals["_CREATECLIENTREQ"]._serialized_end = 278
    _globals["_CREATECLIENTRESP"]._serialized_start = 280
    _globals["_CREATECLIENTRESP"]._serialized_end = 351
    _globals["_DELETECLIENTREQ"]._serialized_start = 353
    _globals["_DELETECLIENTREQ"]._serialized_end = 382
    _globals["_DELETECLIENTRESP"]._serialized_start = 384
    _globals["_DELETECLIENTRESP"]._serialized_end = 421
    _globals["_UPDATECLIENTREQ"]._serialized_start = 423
    _globals["_UPDATECLIENTREQ"]._serialized_end = 530
    _globals["_UPDATECLIENTRESP"]._serialized_start = 532
    _globals["_UPDATECLIENTRESP"]._serialized_end = 569
    _globals["_PASSWORD"]._serialized_start = 571
    _globals["_PASSWORD"]._serialized_end = 645
    _globals["_CREATEPASSWORDREQ"]._serialized_start = 647
    _globals["_CREATEPASSWORDREQ"]._serialized_end = 699
    _globals["_CREATEPASSWORDRESP"]._serialized_start = 701
    _globals["_CREATEPASSWORDRESP"]._serialized_end = 745
    _globals["_UPDATEPASSWORDREQ"]._serialized_start = 747
    _globals["_UPDATEPASSWORDREQ"]._serialized_end = 821
    _globals["_UPDATEPASSWORDRESP"]._serialized_start = 823
    _globals["_UPDATEPASSWORDRESP"]._serialized_end = 862
    _globals["_DELETEPASSWORDREQ"]._serialized_start = 864
    _globals["_DELETEPASSWORDREQ"]._serialized_end = 898
    _globals["_DELETEPASSWORDRESP"]._serialized_start = 900
    _globals["_DELETEPASSWORDRESP"]._serialized_end = 939
    _globals["_LISTPASSWORDREQ"]._serialized_start = 941
    _globals["_LISTPASSWORDREQ"]._serialized_end = 958
    _globals["_LISTPASSWORDRESP"]._serialized_start = 960
    _globals["_LISTPASSWORDRESP"]._serialized_end = 1012
    _globals["_VERSIONREQ"]._serialized_start = 1014
    _globals["_VERSIONREQ"]._serialized_end = 1026
    _globals["_VERSIONRESP"]._serialized_start = 1028
    _globals["_VERSIONRESP"]._serialized_end = 1070
    _globals["_REFRESHTOKENREF"]._serialized_start = 1072
    _globals["_REFRESHTOKENREF"]._serialized_end = 1159
    _globals["_LISTREFRESHREQ"]._serialized_start = 1161
    _globals["_LISTREFRESHREQ"]._serialized_end = 1194
    _globals["_LISTREFRESHRESP"]._serialized_start = 1196
    _globals["_LISTREFRESHRESP"]._serialized_end = 1259
    _globals["_REVOKEREFRESHREQ"]._serialized_start = 1261
    _globals["_REVOKEREFRESHREQ"]._serialized_end = 1315
    _globals["_REVOKEREFRESHRESP"]._serialized_start = 1317
    _globals["_REVOKEREFRESHRESP"]._serialized_end = 1355
    _globals["_VERIFYPASSWORDREQ"]._serialized_start = 1357
    _globals["_VERIFYPASSWORDREQ"]._serialized_end = 1409
    _globals["_VERIFYPASSWORDRESP"]._serialized_start = 1411
    _globals["_VERIFYPASSWORDRESP"]._serialized_end = 1468
    _globals["_DEX"]._serialized_start = 1471
    _globals["_DEX"]._serialized_end = 2236
# @@protoc_insertion_point(module_scope)
